import * as pj from 'projen';
export interface WorkflowOptions {
    readonly workflowName: string;
    readonly definitionFile: string;
}
interface VariableDefinition {
    readonly fullName: string;
    readonly name: string;
    readonly type: string;
}
/**
 * The Workflow construct sets up an AWS Step Functions workflow for a serverless project using projen.
 * This construct extends the projen Component to generate a sample state machine definition file and corresponding TypeScript construct file.
 *
 * @example
 * const workflow = new Workflow(app, {
 *   workflowName: 'MyWorkflow',
 *   definitionFile: 'statemachine/definition.json',
 * });
 */
export declare class Workflow extends pj.Component {
    protected options: WorkflowOptions;
    /**
     * Creates an instance of Workflow.
     *
     * @param app - The AWS CDK TypeScript app.
     * @param options - The options for configuring the Workflow.
     */
    constructor(app: pj.awscdk.AwsCdkTypeScriptApp, options: WorkflowOptions);
    /**
     * Creates the construct file content for the generated Workflow.
     *
     * @param file - The file object to create content for.
     * @returns The content of the construct file.
     */
    protected createConstructFile(file: pj.FileBase): string;
    /**
     * Renders the state configuration definition for a given variable.
     *
     * @param def - The variable definition.
     * @returns The state configuration definition string.
     */
    protected renderStateConfigDefinition(def: VariableDefinition): string;
    /**
     * Renders the definition substitution for a given variable.
     *
     * @param def - The variable definition.
     * @returns The definition substitution string.
     */
    protected renderDefinitionSubstitution(def: VariableDefinition): string;
}
export {};
